@@ -13,7 +13,6 @@ use crate::file::{display_path, remove_all, remove_all_with_warning};
 use crate::install_context::InstallContext;
 use crate::plugins::core::CORE_PLUGINS;
 use crate::plugins::{Plugin, PluginType, VERSION_REGEX};
-use crate::registry::REGISTRY_BACKEND_MAP;
 use crate::runtime_symlinks::is_runtime_symlink;
 use crate::toolset::{
     install_state, is_outdated_version, ToolRequest, ToolSource, ToolVersion, Toolset,
@@ -176,15 +175,7 @@ pub trait Backend: Debug + Send + Sync {
         let mut deps: IndexSet<_> = self
             .get_dependencies(tvr)?
             .into_iter()
-            .flat_map(|ba| {
-                let short = ba.short.clone();
-                [ba].into_iter().chain(
-                    REGISTRY_BACKEND_MAP
-                        .get(short.as_str())
-                        .cloned()
-                        .unwrap_or_default(),
-                )
-            })
+            .filter(|ba| self.ba() != ba) // prevent infinite loop
             .collect();
         let dep_backends = deps
             .iter()
@@ -192,7 +183,11 @@ pub trait Backend: Debug + Send + Sync {
             .collect::<Vec<ABackend>>();
         for dep in dep_backends {
             // TODO: pass the right tvr
-            let tvr = ToolRequest::System(dep.id().into(), ToolSource::Unknown);
+            let tvr = ToolRequest::System {
+                backend: dep.id().into(),
+                source: ToolSource::Unknown,
+                os: None,
+            };
             deps.extend(dep.get_all_dependencies(&tvr)?);
         }
         Ok(deps.into_iter().collect())
@@ -241,7 +236,7 @@ pub trait Backend: Debug + Send + Sync {
     }
     fn is_version_installed(&self, tv: &ToolVersion, check_symlink: bool) -> bool {
         match tv.request {
-            ToolRequest::System(..) => true,
+            ToolRequest::System { .. } => true,
             _ => {
                 let check_path = |install_path: &Path| {
                     let is_installed = install_path.exists();
@@ -337,7 +332,11 @@ pub trait Backend: Debug + Send + Sync {
 
     fn ensure_dependencies_installed(&self) -> eyre::Result<()> {
         let deps = self
-            .get_all_dependencies(&ToolRequest::System(self.id().into(), ToolSource::Unknown))?
+            .get_all_dependencies(&ToolRequest::System {
+                backend: self.id().into(),
+                source: ToolSource::Unknown,
+                os: None,
+            })?
             .into_iter()
             .collect::<HashSet<_>>();
         if !deps.is_empty() {
@@ -392,11 +391,7 @@ pub trait Backend: Debug + Send + Sync {
 
         if let Err(e) = self.install_version_impl(&ctx) {
             self.cleanup_install_dirs_on_error(&ctx.tv);
-            return Err(e.wrap_err(format!(
-                "Failed to install {}@{}",
-                self.id(),
-                ctx.tv.version
-            )));
+            return Err(e);
         }
 
         self.write_backend_meta()?;
@@ -473,7 +468,7 @@ pub trait Backend: Debug + Send + Sync {
     }
     fn list_bin_paths(&self, tv: &ToolVersion) -> eyre::Result<Vec<PathBuf>> {
         match tv.request {
-            ToolRequest::System(..) => Ok(vec![]),
+            ToolRequest::System { .. } => Ok(vec![]),
             _ => Ok(vec![tv.install_path().join("bin")]),
         }
     }
@@ -493,9 +488,21 @@ pub trait Backend: Debug + Send + Sync {
             .into_iter()
             .filter(|p| p.parent().is_some());
         for bin_path in bin_paths {
-            let bin_path = bin_path.join(bin_name);
-            if bin_path.exists() {
-                return Ok(Some(bin_path));
+            let paths_with_ext = if cfg!(windows) {
+                vec![
+                    bin_path.clone(),
+                    bin_path.join(bin_name).with_extension("exe"),
+                    bin_path.join(bin_name).with_extension("cmd"),
+                    bin_path.join(bin_name).with_extension("bat"),
+                    bin_path.join(bin_name).with_extension("ps1"),
+                ]
+            } else {
+                vec![bin_path.join(bin_name)]
+            };
+            for bin_path in paths_with_ext {
+                if bin_path.exists() && file::is_executable(&bin_path) {
+                    return Ok(Some(bin_path));
+                }
             }
         }
         Ok(None)
@@ -530,10 +537,11 @@ pub trait Backend: Debug + Send + Sync {
     fn dependency_toolset(&self) -> eyre::Result<Toolset> {
         let config = Config::get();
         let dependencies = self
-            .get_all_dependencies(&ToolRequest::System(
-                self.name().into(),
-                ToolSource::Unknown,
-            ))?
+            .get_all_dependencies(&ToolRequest::System {
+                backend: self.name().into(),
+                source: ToolSource::Unknown,
+                os: None,
+            })?
             .into_iter()
             .collect();
         let mut ts: Toolset = config
