@@ -1,4 +1,5 @@
-use crate::backend::{Backend, BackendType};
+use crate::backend::backend_type::BackendType;
+use crate::backend::Backend;
 use crate::cache::{CacheManager, CacheManagerBuilder};
 use crate::cli::args::BackendArg;
 use crate::cmd::CmdLineRunner;
@@ -29,7 +30,7 @@ impl Backend for SPMBackend {
         BackendType::Spm
     }
 
-    fn fa(&self) -> &BackendArg {
+    fn ba(&self) -> &BackendArg {
         &self.ba
     }
 
