@@ -19,7 +19,7 @@ pub struct AliasGet {
 impl AliasGet {
     pub fn run(self) -> Result<()> {
         let config = Config::try_get()?;
-        match config.get_all_aliases().get(&self.plugin.short) {
+        match config.all_aliases.get(&self.plugin.short) {
             Some(alias) => match alias.versions.get(&self.alias) {
                 Some(alias) => {
                     miseprintln!("{alias}");
