@@ -1,7 +1,7 @@
 use crate::backend::backend_type::BackendType;
 use crate::backend::{unalias_backend, ABackend};
 use crate::config::CONFIG;
-use crate::registry::REGISTRY_BACKEND_MAP;
+use crate::registry::REGISTRY;
 use crate::toolset::{install_state, parse_tool_options, ToolVersionOptions};
 use crate::{backend, config, dirs};
 use contracts::requires;
@@ -36,13 +36,14 @@ pub struct BackendArg {
 impl<A: AsRef<str>> From<A> for BackendArg {
     fn from(s: A) -> Self {
         let s = s.as_ref();
-        if let Some(ba) = REGISTRY_BACKEND_MAP
-            .get(unalias_backend(s))
-            .and_then(|rbm| rbm.first())
+        let short = unalias_backend(s).to_string();
+        if let Some(backend) = REGISTRY
+            .get(&s)
+            .and_then(|rbm| rbm.backends().first().copied())
         {
-            ba.clone()
+            BackendArg::new(short, Some(backend.to_string()))
         } else {
-            Self::new(s.to_string(), None)
+            Self::new(short, None)
         }
     }
 }
@@ -141,6 +142,20 @@ impl BackendArg {
         }
         unalias_backend(&self.short).to_string()
     }
+
+    pub fn is_os_supported(&self) -> bool {
+        if self.uses_plugin() {
+            return true;
+        }
+        if let Some(rt) = REGISTRY.get(self.short.as_str()) {
+            return rt.is_supported_os();
+        }
+        true
+    }
+
+    pub fn uses_plugin(&self) -> bool {
+        install_state::get_plugin_type(&self.short).is_ok_and(|pt| pt.is_some())
+    }
 }
 
 impl Display for BackendArg {
