@@ -49,6 +49,7 @@ mod settings;
 mod shell;
 mod sync;
 mod tasks;
+mod test_tool;
 mod trust;
 mod uninstall;
 mod unset;
@@ -101,6 +102,7 @@ pub enum Commands {
     Shell(shell::Shell),
     Sync(sync::Sync),
     Tasks(tasks::Tasks),
+    TestTool(test_tool::TestTool),
     Trust(trust::Trust),
     Uninstall(uninstall::Uninstall),
     Unset(unset::Unset),
@@ -159,6 +161,7 @@ impl Commands {
             Self::Shell(cmd) => cmd.run(),
             Self::Sync(cmd) => cmd.run(),
             Self::Tasks(cmd) => cmd.run(),
+            Self::TestTool(cmd) => cmd.run(),
             Self::Trust(cmd) => cmd.run(),
             Self::Uninstall(cmd) => cmd.run(),
             Self::Unset(cmd) => cmd.run(),
