@@ -1,14 +1,14 @@
 use eyre::Result;
 use once_cell::sync::Lazy;
 use std::ffi::OsString;
-use std::path::PathBuf;
 use std::sync::Arc;
 
 pub use python::PythonPlugin;
 
 use crate::backend::{Backend, BackendMap};
 use crate::cli::args::BackendArg;
-use crate::config::{Settings, SETTINGS};
+use crate::config::SETTINGS;
+use crate::env;
 use crate::env::PATH_KEY;
 #[cfg(unix)]
 use crate::plugins::core::bun::BunPlugin;
@@ -21,10 +21,8 @@ use crate::plugins::core::node::NodePlugin;
 use crate::plugins::core::ruby::RubyPlugin;
 #[cfg(unix)]
 use crate::plugins::core::zig::ZigPlugin;
-use crate::plugins::{Plugin, PluginList, PluginType};
 use crate::timeout::run_with_timeout;
 use crate::toolset::ToolVersion;
-use crate::{dirs, env};
 
 #[cfg(unix)]
 mod bun;
@@ -71,64 +69,25 @@ pub static CORE_PLUGINS: Lazy<BackendMap> = Lazy::new(|| {
         .collect()
 });
 
-// TODO: remove this struct
-#[derive(Debug)]
-pub struct CorePlugin {
-    pub fa: BackendArg,
+pub fn path_env_with_tv_path(tv: &ToolVersion) -> Result<OsString> {
+    let mut path = env::split_paths(&env::var_os(&*PATH_KEY).unwrap()).collect::<Vec<_>>();
+    path.insert(0, tv.install_path().join("bin"));
+    Ok(env::join_paths(path)?)
 }
 
-impl CorePlugin {
-    pub fn list() -> PluginList {
-        let settings = Settings::get();
-        CORE_PLUGINS
-            .iter()
-            .map(|(id, _)| Box::new(CorePlugin::new(id.to_string().into())) as Box<dyn Plugin>)
-            .filter(|p| !settings.disable_tools.contains(p.name()))
-            .collect()
-    }
-
-    pub fn new(fa: BackendArg) -> Self {
-        Self { fa }
-    }
-
-    pub fn path_env_with_tv_path(tv: &ToolVersion) -> Result<OsString> {
-        let mut path = env::split_paths(&env::var_os(&*PATH_KEY).unwrap()).collect::<Vec<_>>();
-        path.insert(0, tv.install_path().join("bin"));
-        Ok(env::join_paths(path)?)
-    }
-
-    pub fn run_fetch_task_with_timeout<F, T>(f: F) -> Result<T>
-    where
-        F: FnOnce() -> Result<T> + Send,
-        T: Send,
-    {
-        run_with_timeout(f, SETTINGS.fetch_remote_versions_timeout())
-    }
+pub fn run_fetch_task_with_timeout<F, T>(f: F) -> Result<T>
+where
+    F: FnOnce() -> Result<T> + Send,
+    T: Send,
+{
+    run_with_timeout(f, SETTINGS.fetch_remote_versions_timeout())
 }
 
-// TODO: remove this since core "plugins" are not plugins, this is legacy from when it was just asdf/core
-impl Plugin for CorePlugin {
-    fn name(&self) -> &str {
-        &self.fa.name
-    }
-
-    fn path(&self) -> PathBuf {
-        dirs::PLUGINS.join(self.name())
-    }
-
-    fn get_plugin_type(&self) -> PluginType {
-        PluginType::Core
-    }
-
-    fn get_remote_url(&self) -> Result<Option<String>> {
-        Ok(None)
-    }
-
-    fn current_abbrev_ref(&self) -> Result<Option<String>> {
-        Ok(None)
-    }
-
-    fn current_sha_short(&self) -> Result<Option<String>> {
-        Ok(None)
-    }
+pub fn new_backend_arg(tool_name: &str) -> BackendArg {
+    BackendArg::new_raw(
+        tool_name.to_string(),
+        Some(format!("core:{}", tool_name)),
+        tool_name.to_string(),
+        None,
+    )
 }
