@@ -1,17 +1,14 @@
-use crate::config::Settings;
 use crate::file::{display_path, remove_all};
 use crate::git::Git;
-use crate::plugins::{Plugin, PluginList, PluginType};
+use crate::plugins::{Plugin, PluginType};
 use crate::result::Result;
 use crate::ui::multi_progress_report::MultiProgressReport;
 use crate::ui::progress_report::SingleReport;
-use crate::{dirs, plugins, registry};
+use crate::{dirs, registry};
 use console::style;
 use contracts::requires;
 use eyre::{eyre, Context, Report};
 use indexmap::{indexmap, IndexMap};
-use once_cell::sync::Lazy;
-use std::collections::BTreeSet;
 use std::path::{Path, PathBuf};
 use std::sync::{mpsc, Mutex, MutexGuard};
 use tokio::runtime::Runtime;
@@ -28,14 +25,6 @@ pub struct VfoxPlugin {
     pub repo_url: Option<String>,
 }
 
-pub static VFOX_PLUGIN_NAMES: Lazy<BTreeSet<String>> = Lazy::new(|| match VfoxPlugin::list() {
-    Ok(plugins) => plugins.into_iter().map(|p| p.name().to_string()).collect(),
-    Err(err) => {
-        warn!("Failed to list vfox plugins: {err}");
-        BTreeSet::new()
-    }
-});
-
 impl VfoxPlugin {
     #[requires(!name.is_empty())]
     pub fn new(name: String) -> Self {
@@ -50,21 +39,6 @@ impl VfoxPlugin {
         }
     }
 
-    pub fn list() -> eyre::Result<PluginList> {
-        let settings = Settings::get();
-        let plugins = plugins::INSTALLED_PLUGINS
-            .iter()
-            .filter(|(_, t)| matches!(t, PluginType::Vfox))
-            .inspect(|(dir, _)| trace!("vfox_plugin: {:?}", dir))
-            .map(|(dir, _)| {
-                let name = dir.file_name().unwrap().to_string_lossy().to_string();
-                Box::new(VfoxPlugin::new(name)) as Box<dyn Plugin>
-            })
-            .filter(|p| !settings.disable_tools.contains(p.name()))
-            .collect();
-        Ok(plugins)
-    }
-
     fn repo(&self) -> MutexGuard<Git> {
         self.repo.lock().unwrap()
     }
@@ -133,6 +107,10 @@ impl Plugin for VfoxPlugin {
         Ok(url.or(self.repo_url.clone()))
     }
 
+    fn set_remote_url(&mut self, url: String) {
+        self.repo_url = Some(url);
+    }
+
     fn current_abbrev_ref(&self) -> eyre::Result<Option<String>> {
         if !self.is_installed() {
             return Ok(None);
@@ -255,8 +233,9 @@ Plugins could support local directories in the future but for now a symlink is r
 
 fn vfox_to_url(name: &str) -> eyre::Result<Url> {
     let name = name.strip_prefix("vfox:").unwrap_or(name);
-    if let Some(full) = registry::REGISTRY_VFOX.get(name.trim_start_matches("vfox-")) {
+    if let Some(rt) = registry::REGISTRY.get(name.trim_start_matches("vfox-")) {
         // bun -> version-fox/vfox-bun
+        let full = rt.backends.iter().find(|f| f.starts_with("vfox:")).unwrap();
         return vfox_to_url(full.split_once(':').unwrap().1);
     }
     let res = if let Some(caps) = regex!(r#"^([^/]+)/([^/]+)$"#).captures(name) {
