@@ -55,7 +55,7 @@ fn which_shim(bin_name: &str) -> Result<PathBuf> {
     }
     if SETTINGS.not_found_auto_install && console::user_attended() {
         for tv in ts.install_missing_bin(bin_name)?.unwrap_or_default() {
-            let p = tv.get_backend();
+            let p = tv.backend()?;
             if let Some(bin) = p.which(&tv, bin_name)? {
                 trace!(
                     "shim[{bin_name}] NOT_FOUND ToolVersion: {tv} bin: {bin}",
@@ -276,17 +276,17 @@ fn err_no_version_set(ts: Toolset, bin_name: &str, tvs: Vec<ToolVersion>) -> Res
     if tvs.is_empty() {
         bail!("{} is not a valid shim", bin_name);
     }
-    let missing_plugins = tvs.iter().map(|tv| tv.backend()).collect::<HashSet<_>>();
+    let missing_plugins = tvs.iter().map(|tv| tv.ba()).collect::<HashSet<_>>();
     let mut missing_tools = ts
         .list_missing_versions()
         .into_iter()
-        .filter(|t| missing_plugins.contains(t.backend()))
+        .filter(|t| missing_plugins.contains(t.ba()))
         .collect_vec();
     if missing_tools.is_empty() {
         let mut msg = format!("No version is set for shim: {}\n", bin_name);
         msg.push_str("Set a global default version with one of the following:\n");
         for tv in tvs {
-            msg.push_str(&format!("mise use -g {}@{}\n", tv.backend(), tv.version));
+            msg.push_str(&format!("mise use -g {}@{}\n", tv.ba(), tv.version));
         }
         Err(eyre!(msg.trim().to_string()))
     } else {
