@@ -137,8 +137,8 @@ pub fn short_to_full(short: &str, meta_full: Option<String>) -> Result<Option<St
         Ok(Some(full))
     } else if let Some(full) = REGISTRY
         .get(short)
-        .map(|r| &r.backends)
-        .unwrap_or(&EMPTY_VEC)
+        .map(|r| r.backends())
+        .unwrap_or_default()
         .first()
     {
         Ok(Some(full.to_string()))
@@ -152,6 +152,11 @@ pub fn list_plugins() -> Result<BTreeMap<String, PluginType>> {
     Ok(plugins.as_ref().unwrap().clone())
 }
 
+pub fn get_plugin_type(short: &str) -> Result<Option<PluginType>> {
+    let plugins = init_plugins()?;
+    Ok(plugins.as_ref().unwrap().get(short).cloned())
+}
+
 pub fn list_tools() -> Result<BTreeMap<String, InstallStateTool>> {
     let tools = init_tools()?;
     Ok(tools.as_ref().unwrap().clone())
@@ -240,8 +245,6 @@ pub fn incomplete_file_path(short: &str, v: &str) -> PathBuf {
         .join("incomplete")
 }
 
-static EMPTY_VEC: Vec<&'static str> = vec![];
-
 pub fn reset() {
     *INSTALL_STATE_PLUGINS.lock().unwrap() = None;
     *INSTALL_STATE_TOOLS.lock().unwrap() = None;
