@@ -91,14 +91,14 @@ impl Toolset {
         }
     }
     pub fn add_version(&mut self, tvr: ToolRequest) {
-        let fa = tvr.ba();
-        if self.is_disabled(fa) {
+        let ba = tvr.ba();
+        if self.is_disabled(ba) {
             return;
         }
         let tvl = self
             .versions
             .entry(tvr.ba().clone())
-            .or_insert_with(|| ToolVersionList::new(fa.clone(), self.source.clone().unwrap()));
+            .or_insert_with(|| ToolVersionList::new(ba.clone(), self.source.clone().unwrap()));
         tvl.requests.push(tvr);
     }
     pub fn merge(&mut self, other: Toolset) {
@@ -152,7 +152,14 @@ impl Toolset {
 
     pub fn list_missing_plugins(&self) -> Vec<String> {
         self.versions
-            .keys()
+            .iter()
+            .filter(|(_, tvl)| {
+                tvl.versions
+                    .first()
+                    .map(|tv| tv.request.is_os_supported())
+                    .unwrap_or_default()
+            })
+            .map(|(ba, _)| ba)
             .flat_map(|ba| ba.backend())
             .filter(|b| b.plugin().is_some_and(|p| !p.is_installed()))
             .map(|p| p.id().into())
@@ -233,7 +240,8 @@ impl Toolset {
                                     tv: tv.clone(),
                                     force: opts.force,
                                 };
-                                t.install_version(ctx)?;
+                                t.install_version(ctx)
+                                    .wrap_err_with(|| format!("failed to install {tv}"))?;
                                 installed.push(tv);
                             }
                             installing.lock().unwrap().remove(t.id());
@@ -288,7 +296,7 @@ impl Toolset {
     pub fn list_missing_versions(&self) -> Vec<ToolVersion> {
         self.list_current_versions()
             .into_iter()
-            .filter(|(p, tv)| !p.is_version_installed(tv, true))
+            .filter(|(p, tv)| tv.request.is_os_supported() && !p.is_version_installed(tv, true))
             .map(|(_, tv)| tv)
             .collect()
     }
@@ -348,6 +356,7 @@ impl Toolset {
                                 backend: p.ba().clone(),
                                 ref_: r.to_string(),
                                 ref_type: ref_type.to_string(),
+                                os: v.request.os().clone(),
                                 options: v.request.options().clone(),
                                 source: v.request.source().clone(),
                             };
@@ -424,12 +433,14 @@ impl Toolset {
                                     version: _version,
                                     options,
                                     source,
+                                    os,
                                 } => {
                                     out.tool_request = ToolRequest::Version {
                                         backend,
                                         options,
                                         source,
                                         version: out.bump.clone().unwrap(),
+                                        os,
                                     };
                                 }
                                 _ => {
@@ -472,7 +483,7 @@ impl Toolset {
         let entries = self
             .list_current_installed_versions()
             .into_par_iter()
-            .filter(|(_, tv)| !matches!(tv.request, ToolRequest::System(..)))
+            .filter(|(_, tv)| !matches!(tv.request, ToolRequest::System { .. }))
             .flat_map(|(p, tv)| match p.exec_env(config, self, &tv) {
                 Ok(env) => env.into_iter().collect(),
                 Err(e) => {
@@ -505,7 +516,7 @@ impl Toolset {
     pub fn list_paths(&self) -> Vec<PathBuf> {
         self.list_current_installed_versions()
             .into_par_iter()
-            .filter(|(_, tv)| !matches!(tv.request, ToolRequest::System(..)))
+            .filter(|(_, tv)| !matches!(tv.request, ToolRequest::System { .. }))
             .flat_map(|(p, tv)| {
                 p.list_bin_paths(&tv).unwrap_or_else(|e| {
                     warn!("Error listing bin paths for {tv}: {e:#}");
@@ -600,9 +611,8 @@ impl Toolset {
         );
     }
 
-    fn is_disabled(&self, fa: &BackendArg) -> bool {
-        let fa = fa.to_string();
-        SETTINGS.disable_tools.iter().any(|s| s == &fa)
+    fn is_disabled(&self, ba: &BackendArg) -> bool {
+        !ba.is_os_supported() || SETTINGS.disable_tools.contains(&ba.short)
     }
 }
 
@@ -635,13 +645,13 @@ impl Display for Toolset {
 impl From<ToolRequestSet> for Toolset {
     fn from(trs: ToolRequestSet) -> Self {
         let mut ts = Toolset::default();
-        for (fa, versions, source) in trs.into_iter() {
+        for (ba, versions, source) in trs.into_iter() {
             ts.source = Some(source.clone());
-            let mut tvl = ToolVersionList::new(fa.clone(), source);
+            let mut tvl = ToolVersionList::new(ba.clone(), source);
             for tr in versions {
                 tvl.requests.push(tr);
             }
-            ts.versions.insert(fa, tvl);
+            ts.versions.insert(ba, tvl);
         }
         ts
     }
